@@ -17,9 +17,9 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 import urllib
-import httplib
 import json
 import sys
+import requests
 
 from PyQt4.QtGui import QMessageBox, QApplication, QPushButton
 
@@ -31,20 +31,12 @@ from electrum.i18n import _
 from electrum.bitcoin import regenerate_key
 
 
-description = _("Allows validating if your transactions have instant confirmations by GreenAddress")
-
 
 class Plugin(BasePlugin):
 
     button_label = _("Verify GA instant")
 
-    def fullname(self):
-        return 'GreenAddress instant'
-
-    def description(self):
-        return description
-
-    @hook 
+    @hook
     def init_qt(self, gui):
         self.win = gui.main_window
 
@@ -53,7 +45,7 @@ class Plugin(BasePlugin):
         self.wallet = d.wallet
         self.verify_button = b = QPushButton(self.button_label)
         b.clicked.connect(lambda: self.do_verify(d.tx))
-        d.buttons.insert(1, b)
+        d.buttons.insert(0, b)
         self.transaction_dialog_update(d)
 
     def get_my_addr(self, tx):
@@ -88,13 +80,12 @@ class Plugin(BasePlugin):
             addr = self.get_my_addr(tx)
             message = "Please verify if %s is GreenAddress instant confirmed" % tx.hash()
             sig = self.wallet.sign_message(addr, message, password)
+            sig = base64.b64encode(sig)
 
             # 2. send the request
-            connection = httplib.HTTPSConnection('greenaddress.it')
-            connection.request("GET", ("/verify/?signature=%s&txhash=%s" % (urllib.quote(sig), tx.hash())),
-                None, {'User-Agent': 'Electrum'})
-            response = connection.getresponse()
-            response = json.loads(response.read())
+            response = requests.request("GET", ("https://greenaddress.it/verify/?signature=%s&txhash=%s" % (urllib.quote(sig), tx.hash())),
+                                        headers = {'User-Agent': 'Electrum'})
+            response = response.json()
 
             # 3. display the result
             if response.get('verified'):
